@@ -32,7 +32,7 @@ def main():
     sub_p = p.add_subparsers(dest='cmd',required=True)
     set_p = sub_p.add_parser('set')
     get_p = sub_p.add_parser('get')
-    set_p.add_argument('text',type=str)
+    set_p.add_argument('text',type=str,nargs='?',default=pyperclip.paste())
     args = p.parse_args()
 
     if args.cmd == 'get':
